@@ -1,7 +1,7 @@
+use clap::Parser;
 use exitfailure::ExitFailure;
 use failure::ResultExt;
 use redis::{Commands, Connection};
-use structopt::StructOpt;
 
 mod util;
 use crate::util::cli::Cli;
@@ -47,12 +47,12 @@ fn main() -> Result<(), ExitFailure> {
     let Cli {
         hostname,
         port,
-        easy_search,
+        use_contains,
         query,
         show_ttl,
         show_value,
         db,
-    } = Cli::from_args();
+    } = Cli::parse();
 
     let connection_string = format!("redis://{}:{}", hostname, port);
 
@@ -65,7 +65,7 @@ fn main() -> Result<(), ExitFailure> {
     let databases =
         get_databases(&mut connection).with_context(|_| "getting the number of databases")?;
 
-    let query = if easy_search {
+    let query = if use_contains {
         let insensitive_query = query
             .chars()
             .map(|c| {
